register_diff_rule

Function register_diff_rule 

pub fn register_diff_rule(symbol: Symbol, rule: DiffRule) -> Result<()>
Register rule for symbol in the global registry.

Errors

Returns an error if the global registry lock is poisoned or a rule already exists for symbol.