CasDiffRegistry

Struct CasDiffRegistry 

pub struct CasDiffRegistry {
    pub rules: BTreeMap<Symbol, DiffRule>,
}
A registry of per-operator differentiation rules.

Examples

use sim_kernel::Symbol;
use sim_lib_numbers_cas::CasExpr;
use sim_lib_numbers_cas_diff::CasDiffRegistry;

let mut registry = CasDiffRegistry::new();
registry.register_rule(
    Symbol::new("id"),
    Box::new(|args: &[CasExpr], _var: &Symbol| args.first().cloned()),
);

let out = registry.apply(
    &Symbol::new("id"),
    &[CasExpr::Var(Symbol::new("x"))],
    &Symbol::new("x"),
);
assert!(matches!(out, Some(CasExpr::Var(_))));
// An unregistered operator yields `None`.
assert!(registry.apply(&Symbol::new("nope"), &[], &Symbol::new("x")).is_none());

Fields

rules: BTreeMap<Symbol, DiffRule>

The registered rules, keyed by operator symbol.

Implementations

Source

impl CasDiffRegistry

pub fn new() -> Self

Construct an empty registry.

pub fn register_rule( &mut self, symbol: Symbol, rule: DiffRule, ) -> Option<DiffRule>

Register rule for symbol, returning any rule it replaced.

pub fn apply( &self, symbol: &Symbol, args: &[CasExpr], var: &Symbol, ) -> Option<CasExpr>

Apply the rule registered for symbol, if any, to args and var.